@@ -22,6 +22,7 @@ const int EXPRESSIONBAR_HEIGHT = 100;
 scientificModule::scientificModule(QWidget *parent)
     : DWidget(parent)
 {
+    qDebug() << "scientificModule constructor called";
     m_stackWidget = new QStackedWidget(this);
     m_sciexpressionBar = new SciExpressionBar(this);
     m_memhiskeypad = new MemHisKeypad(this);
@@ -80,13 +81,21 @@ scientificModule::scientificModule(QWidget *parent)
     connect(m_memhiswidget->findChild<MemoryWidget *>(), &MemoryWidget::widgetplus, this, [ = ](int row) {
         //点击键盘按键上的m+,m-是先进行计算，若有计算结果放入内存中
         m_sciexpressionBar->enterEqualEvent();
-        if (m_sciexpressionBar->getInputEdit()->getMemoryAnswer().first)
+        if (m_sciexpressionBar->getInputEdit()->getMemoryAnswer().first) {
+            qDebug() << "Performing memory plus operation";
             m_memhiswidget->memoryFunctions(MemHisWidget::widgetplus, m_sciexpressionBar->getInputEdit()->getMemoryAnswer().second, row);
+        } else {
+            qWarning() << "Cannot perform memory plus - invalid memory answer";
+        }
     });
     connect(m_memhiswidget->findChild<MemoryWidget *>(), &MemoryWidget::widgetminus, this, [ = ](int row) {
         m_sciexpressionBar->enterEqualEvent();
-        if (m_sciexpressionBar->getInputEdit()->getMemoryAnswer().first)
+        if (m_sciexpressionBar->getInputEdit()->getMemoryAnswer().first) {
+            qDebug() << "Performing memory minus operation";
             m_memhiswidget->memoryFunctions(MemHisWidget::widgetminus, m_sciexpressionBar->getInputEdit()->getMemoryAnswer().second, row);
+        } else {
+            qWarning() << "Cannot perform memory minus - invalid memory answer";
+        }
     });
     connect(m_memoryPublic, &MemoryPublic::memorycleanSig, this, &scientificModule::mUnAvailableEvent);
     connect(m_memoryPublic, &MemoryPublic::generateDataSig, this, &scientificModule::mAvailableEvent);
@@ -148,14 +157,20 @@ scientificModule::scientificModule(QWidget *parent)
         }
     });
 
-    if (!m_memoryPublic->isEmpty())
+    if (!m_memoryPublic->isEmpty()) {
+        qDebug() << "Memory is not empty, triggering available event";
         mAvailableEvent();
-    else
+    } else {
+        qDebug() << "Memory is empty, triggering unavailable event";
         mUnAvailableEvent();
+    }
 //    setScientificTabOrder();
 }
 
-scientificModule::~scientificModule() {}
+scientificModule::~scientificModule()
+{
+    qDebug() << "scientificModule destructor called";
+}
 
 void scientificModule::initTheme(int type)
 {
@@ -168,6 +183,7 @@ void scientificModule::initTheme(int type)
  */
 void scientificModule::handleEditKeyPress(QKeyEvent *e)
 {
+    qDebug() << "handleEditKeyPress called with key:" << e->key();
     const bool isPressCtrl = e->modifiers() == Qt::ControlModifier; //ctrl是否按下
     const bool isPressShift = e->modifiers() == Qt::ShiftModifier; //shift是否按下
 
@@ -235,6 +251,7 @@ void scientificModule::handleEditKeyPress(QKeyEvent *e)
         m_sciexpressionBar->enterEqualEvent();
         m_scikeypadwidget->animate(ScientificKeyPad::Key_Equals);
         if (m_sciexpressionBar->getexpression().first) {
+            qDebug() << "Updating history list with new calculation";
             m_memhiswidget->findChild<SimpleListModel *>()->updataList(m_sciexpressionBar->getanswer(), m_sciexpressionBar->getexpression().second, 0);
             m_memhiswidget->historyfilled();
             m_memhiswidget->findChild<SimpleListView *>()->scrollToTop();
@@ -484,6 +501,8 @@ void scientificModule::handleEditKeyPress(QKeyEvent *e)
  */
 void scientificModule::handleKeypadButtonPress(int key)
 {
+    qDebug() << "handleKeypadButtonPress called with key:" << key;
+
     bool pagefocus = false;
     m_scikeypadwidget->update();
     //20200414 bug20294鼠标点击取消focus
